import logging
import tomllib
from pathlib import Path

from hasspy.mqtt import HassClient


def main() -> None:
    logging.basicConfig(level=logging.INFO)

    config_file = next(
        (
            x
            for x in (Path("/etc/hasspy.toml"), Path("/etc/hasspy/config.toml"))
            if x.exists()
        ),
        None,
    )
    if not config_file:
        raise FileNotFoundError("No configuration file found")

    with open(config_file, "rb") as file:
        config = tomllib.load(file)

    ha = HassClient(
        "orchomenos",
        config=config,
    )

    ha.loop_forever()


if __name__ == "__main__":
    main()
